@@ -1,7 +1,6 @@
 package Search::Elasticsearch::Client::1_0::Role::API;
-$Search::Elasticsearch::Client::1_0::Role::API::VERSION = '6.80_01'; # TRIAL
-
-$Search::Elasticsearch::Client::1_0::Role::API::VERSION = '6.8001';use Moo::Role;
+$Search::Elasticsearch::Client::1_0::Role::API::VERSION = '6.81';
+use Moo::Role;
 with 'Search::Elasticsearch::Role::API';
 
 use Search::Elasticsearch::Util qw(throw);
@@ -2032,7 +2031,7 @@ Search::Elasticsearch::Client::1_0::Role::API - This class contains the spec for
 
 =head1 VERSION
 
-version 6.80_01
+version 6.81
 
 =head1 DESCRIPTION
 
